# FDI API

This is a API description of FDI(Flexible Dataset Integrator) server
More information: https://helloreverb.com
Contact Info: syx1026@qq.com
Version: 1.0.0
BasePath:/yuxinvalo/fdi/1.0.0
Apache 2.0
http://www.apache.org/licenses/LICENSE-2.0.html

## Access

## Methods

[ Jump to Models ]

### Table of Contents

#### Default

- `delete /httppool/{poolid}`
- `get /httppool/{poolid}/hk`
- `get /httppool/{poolid}/hk/{metadata}`
- `delete /httppool/{poolid}/{product}/{sn}`
- `get /httppool/{poolid}/{product}/{sn}`
- `post /httppool/{poolid}/{product}/{sn}`

# Default

Up

    delete /httppool/{poolid}

request a product in the pools by passing pool id, product type and its index (httppoolPoolidDelete)
request a product in the pools by passing pool id, product type and its index

### Path parameters

poolid (required)
Path Parameter — pass an complete pool id

### Consumes

This API call consumes the following media types via the Content-Type request header:

- `application/json`

### Return type

array[generateok]

### Example data

Content-Type: application/json

    [ {
      "result" : "result",
      "msg" : "OK",
      "ts" : "1.5948800582498861E10"
    }, {
      "result" : "result",
      "msg" : "OK",
      "ts" : "1.5948800582498861E10"
    } ]

### Produces

This API call produces the following media types according to the Accept request header; the media type will be conveyed by the Content-Type response header.

- `application/json`

### Responses

#### 200

wiping all pool done

#### 400

pool is invalid or pool is busy at the moment

Up

    get /httppool/{poolid}/hk

Read housekeeping from server. (httppoolPoolidHkGet)
By passing in the appropriate pool id, you can search for housekeeping data of a pool which was registred in server.

### Path parameters

poolid (required)
Path Parameter — pass an complete pool id

### Return type

array[hkdata]

### Example data

Content-Type: application/json

    [ {
      "result" : [ {
        "urns" : {
          "urn" : "urn",
          "meta" : "meta"
        },
        "classes" : [ {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        }, {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        } ],
        "tags" : "tags"
      }, {
        "urns" : {
          "urn" : "urn",
          "meta" : "meta"
        },
        "classes" : [ {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        }, {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        } ],
        "tags" : "tags"
      } ],
      "msg" : "OK",
      "ts" : "1.5948800582498861E10"
    }, {
      "result" : [ {
        "urns" : {
          "urn" : "urn",
          "meta" : "meta"
        },
        "classes" : [ {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        }, {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        } ],
        "tags" : "tags"
      }, {
        "urns" : {
          "urn" : "urn",
          "meta" : "meta"
        },
        "classes" : [ {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        }, {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        } ],
        "tags" : "tags"
      } ],
      "msg" : "OK",
      "ts" : "1.5948800582498861E10"
    } ]

### Produces

This API call produces the following media types according to the Accept request header; the media type will be conveyed by the Content-Type response header.

- `application/json`

### Responses

#### 200

return housekeeping of pool id that user specifiy

#### 400

pool id doesn't exist or pool is busy at the moment

Up

    get /httppool/{poolid}/hk/{metadata}

request a product in the pools by passing pool id, product type and its index (httppoolPoolidHkMetadataGet)
request a product in the pools by passing pool id, product type and its index

### Path parameters

poolid (required)
Path Parameter — pass an complete pool id
metadata (required)
Path Parameter — one of the three metadata classes, urns, tags

### Consumes

This API call consumes the following media types via the Content-Type request header:

- `application/json`

### Return type

array[hkdata]

### Example data

Content-Type: application/json

    [ {
      "result" : [ {
        "urns" : {
          "urn" : "urn",
          "meta" : "meta"
        },
        "classes" : [ {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        }, {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        } ],
        "tags" : "tags"
      }, {
        "urns" : {
          "urn" : "urn",
          "meta" : "meta"
        },
        "classes" : [ {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        }, {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        } ],
        "tags" : "tags"
      } ],
      "msg" : "OK",
      "ts" : "1.5948800582498861E10"
    }, {
      "result" : [ {
        "urns" : {
          "urn" : "urn",
          "meta" : "meta"
        },
        "classes" : [ {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        }, {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        } ],
        "tags" : "tags"
      }, {
        "urns" : {
          "urn" : "urn",
          "meta" : "meta"
        },
        "classes" : [ {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        }, {
          "currentSN" : 6,
          "fdi.dataset.product.Product" : [ 0, 0 ]
        } ],
        "tags" : "tags"
      } ],
      "msg" : "OK",
      "ts" : "1.5948800582498861E10"
    } ]

### Produces

This API call produces the following media types according to the Accept request header; the media type will be conveyed by the Content-Type response header.

- `application/json`

### Responses

#### 200

return one of the metadata of pool id that user specifiy

#### 400

pool id doesn't exist or pool is busy at the moment

Up

    delete /httppool/{poolid}/{product}/{sn}

delete a product from server (httppoolPoolidProductSnDelete)
delete a product to server by specifying product pool, type and index

### Path parameters

poolid (required)
Path Parameter — pass an complete pool id
product (required)
Path Parameter — class of product
sn (required)
Path Parameter — index of product that user want to retreive

### Consumes

This API call consumes the following media types via the Content-Type request header:

- `application/json`

### Return type

array[generateok]

### Example data

Content-Type: application/json

    [ {
      "result" : "result",
      "msg" : "OK",
      "ts" : "1.5948800582498861E10"
    }, {
      "result" : "result",
      "msg" : "OK",
      "ts" : "1.5948800582498861E10"
    } ]

### Produces

This API call produces the following media types according to the Accept request header; the media type will be conveyed by the Content-Type response header.

- `application/json`

### Responses

#### 200

product created and saved

#### 400

product is invalid or pool is busy at the moment

Up

    get /httppool/{poolid}/{product}/{sn}

request a product in the pools by passing pool id, product type and its index (httppoolPoolidProductSnGet)
request a product in the pools by passing pool id, product type and its index

### Path parameters

poolid (required)
Path Parameter — pass an complete pool id
product (required)
Path Parameter — class of product
sn (required)
Path Parameter — index of product that user want to retreive

### Consumes

This API call consumes the following media types via the Content-Type request header:

- `application/json`

### Return type

array[product]

### Example data

Content-Type: application/json

    [ {
      "result" : [ {
        "meta" : [ {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        }, {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        } ]
      }, {
        "meta" : [ {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        }, {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        } ]
      } ],
      "msg" : "OK",
      "ts" : "1.5948800582498861E10"
    }, {
      "result" : [ {
        "meta" : [ {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        }, {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        } ]
      }, {
        "meta" : [ {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        }, {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        } ]
      } ],
      "msg" : "OK",
      "ts" : "1.5948800582498861E10"
    } ]

### Produces

This API call produces the following media types according to the Accept request header; the media type will be conveyed by the Content-Type response header.

- `application/json`

### Responses

#### 200

return the product specified in path back if it exists and available

#### 400

product doesn't exist or pool is busy at the moment

Up

    post /httppool/{poolid}/{product}/{sn}

upload a product to server (httppoolPoolidProductSnPost)
upload a product to server

### Path parameters

poolid (required)
Path Parameter — pass an complete pool id
product (required)
Path Parameter — class of product
sn (required)
Path Parameter — index of product that user want to retreive

### Consumes

This API call consumes the following media types via the Content-Type request header:

- `application/json`

### Return type

array[productref]

### Example data

Content-Type: application/json

    [ {
      "result" : [ {
        "meta" : [ {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        }, {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        } ],
        "urnobj" : [ {
          "urn" : "urn",
          "_STID" : 0
        }, {
          "urn" : "urn",
          "_STID" : 0
        } ]
      }, {
        "meta" : [ {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        }, {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        } ],
        "urnobj" : [ {
          "urn" : "urn",
          "_STID" : 0
        }, {
          "urn" : "urn",
          "_STID" : 0
        } ]
      } ],
      "msg" : "OK",
      "ts" : "1.5948800582498861E10"
    }, {
      "result" : [ {
        "meta" : [ {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        }, {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        } ],
        "urnobj" : [ {
          "urn" : "urn",
          "_STID" : 0
        }, {
          "urn" : "urn",
          "_STID" : 0
        } ]
      }, {
        "meta" : [ {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        }, {
          "creator" : "creator",
          "etc" : "etc",
          "description" : "description",
          "type" : "type",
          "creationDate" : "2000-01-23T04:56:07.000+00:00"
        } ],
        "urnobj" : [ {
          "urn" : "urn",
          "_STID" : 0
        }, {
          "urn" : "urn",
          "_STID" : 0
        } ]
      } ],
      "msg" : "OK",
      "ts" : "1.5948800582498861E10"
    } ]

### Produces

This API call produces the following media types according to the Accept request header; the media type will be conveyed by the Content-Type response header.

- `application/json`

### Responses

#### 200

item created

#### 400

product is invalid or pool is busy at the moment

## Models

[ Jump to Methods ]

### Table of Contents

1. `generatebad` -
2. `generateok` -
3. `hkdata` -
4. `hkdata_classes` -
5. `hkdata_result` -
6. `hkdata_urns` -
7. `product` -
8. `product_meta` -
9. `product_result` -
10. `productref` -
11. `productref_result` -
12. `productref_urnobj` -

### `generatebad` - Up

result
String
example: FAILED
msg
String
example: pool is not available
ts
String format: ^\d{10}.d{6}
example: 1.5948800582498861E10

### `generateok` - Up

result
String
msg
String
example: OK
ts
String format: ^\d{10}.d{6}
example: 1.5948800582498861E10

### `hkdata` - Up

result
array[hkdata_result]
msg
String
example: OK
ts
String format: ^\d{10}.d{6}
example: 1.5948800582498861E10

### `hkdata_classes` - Up

fdi.dataset.product.Product (optional)
array[Long] format: int64
currentSN (optional)
Long format: int64

### `hkdata_result` - Up

classes (optional)
array[hkdata_classes]
tags (optional)
String
urns (optional)
hkdata_urns

### `hkdata_urns` - Up

urn (optional)
String
meta (optional)
String

### `product` - Up

result
array[product_result]
msg
String
example: OK
ts (optional)
String format: ^\d{10}.d{6}
example: 1.5948800582498861E10

### `product_meta` - Up

description (optional)
String
type (optional)
String
creator (optional)
String
creationDate (optional)
Date format: date-time
etc (optional)
String

### `product_result` - Up

meta (optional)
array[product_meta]

### `productref` - Up

result
array[productref_result]
msg
String
example: OK
ts (optional)
String format: ^\d{10}.d{6}
example: 1.5948800582498861E10

### `productref_result` - Up

urnobj (optional)
array[productref_urnobj]
meta (optional)
array[product_meta]

### `productref_urnobj` - Up

urn (optional)
String
_STID (optional)
Long format: int64